# ROSH - Router Shell

**WARNING** *This project is still in an early stage of development, and most of its intended function is missing!*

This is a interactive diagnostic shell for (software|linux)-based routers. It's inspired by the CLI of network equipment (i.e. Cisco IOS) and implements simular diagnostic commands like the iproute2/bridge/ethtool/tc/wireguard commands.

![rosh demo](doc/demo.gif)
